@@ -5,4 +5,6 @@ quality financial algorithms to be used freely.
 Todo:
     * NA
 """
-from .lib import *
+from ._lib import IndexHold, ThetaGang, TemplateAlgo
+
+__all__ = ["IndexHold", "ThetaGang", "TemplateAlgo"]
